@@ -11,7 +11,7 @@ has 'depth' => 0;
 has 'additional_props' => sub { {} };
 has 'redirect_history' => sub { [] };
 has 'method' => 'get';
-has 'tx_params' => sub { [] };
+has 'tx_params';
 
 sub clone {
     my $self = shift;
